@@ -26,7 +26,7 @@ def get_roles(provided_roles: Union[List[str], ServicerContext]):
     return provided_roles
 
 
-def is_authorized(provided_roles: Union[List[str], ServicerContext], required_roles: List[str], decission_logic: str = 'all'):
+def is_authorized(provided_roles: Union[List[str], ServicerContext], required_roles: List[str], decission_logic: str = 'all', abort: bool = False):
   """
   Makes a decision if user is authorized based on intersection of roles.
 
@@ -34,20 +34,26 @@ def is_authorized(provided_roles: Union[List[str], ServicerContext], required_ro
     a list of roles or the grpc context passed to class methods
   :param List[str] required_roles: roles the request must pass
   :param str decission_logic: one of 'all' or 'some'. Default: 'all'
+  :param bool abort: if set to true grpc call will abort with PERMISSION_DENIED. Default: False
   :rtype: bool
   """
 
   assert len(required_roles) != 0
   assert type(required_roles) == list
   assert any([allowed == decission_logic for allowed in ['all', 'some']])
-  provided_roles = get_roles(provided_roles)
+  resolved_roles = get_roles(provided_roles)
 
   required_roles = set(required_roles)  # in case same role is passed mulitple times
-  role_intersection = required_roles.intersection(provided_roles)
+  role_intersection = required_roles.intersection(resolved_roles)
   all_intersects = len(role_intersection) == len(required_roles)
   some_intersects = len(role_intersection) > 0
-  return ((decission_logic == 'all' and all_intersects) or
+  _is_authorized = ((decission_logic == 'all' and all_intersects) or
           (decission_logic == 'some' and some_intersects))
+  is_grpc_context = type(provided_roles) is not list
+  if abort and not is_authorized and is_grpc_context:
+    details = f'Provided roles {resolved_roles} don\'t intersect with required roles {required_roles}.'
+    provided_roles.abort(StatusCode.PERMISSION_DENIED, details)
+  return _is_authorized
 
 
 def authorize(required_roles: List[str], decission_logic: str = 'all'):
