@@ -53,3 +53,21 @@ def get_affiliation(context: ServicerContext) -> Union[Tuple[str, str], None]:
     return None
   else:
     return raw_groups[0].split('/')[1:3]
+
+
+def get_user_and_client_ids(context: ServicerContext) -> Tuple[str, str]:
+  """
+  Get user_id and client_id.
+
+  :param grpc.aio.ServicerContext context: context passed to grpc endpoints
+  :return user_id and client_id.
+    More information: https://wiki.delphai.dev/wiki/Authorization
+  :rtype: Tuple[str, str]
+  """
+  try:
+    user = get_user(context)
+    user_id = user.get('https://delphai.com/mongo_user_id')
+    client_id = user.get('https://delphai.com/client_id')
+  except Exception:
+    return '', ''
+  return user_id, client_id
